@@ -3,7 +3,7 @@ package Module::List::More;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-21'; # DATE
 our $DIST = 'Module-List-More'; # DIST
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 #IFUNBUILT
 # # use strict 'subs', 'vars';
@@ -242,7 +242,7 @@ Module::List::More - Module::List, with more options
 
 =head1 VERSION
 
-This document describes version 0.004007 of Module::List::More (from Perl distribution Module-List-More), released on 2020-09-21.
+This document describes version 0.004008 of Module::List::More (from Perl distribution Module-List-More), released on 2020-09-21.
 
 =head1 SYNOPSIS
 
@@ -306,10 +306,12 @@ will be an arrayref containing all found paths.
 If set to true, will return a C<library_path> result key, which is the
 associated @INC entry that produces the result.
 
-=item * Recognize C<return_library_path> option
+=item * Recognize C<return_version> option
 
 If set to true, will parse module source file with L<ExtUtils::MakeMaker>'s
-C<parse_version> and return the result in C<module_version> key.
+C<parse_version> and return the result in C<module_version> key. If version
+cannot be detected, a proper undefined value C<undef> (instead of the string
+C<'undef'>) is returned.
 
 =item * Recognize C<wildcard> option
 
